@@ -87,23 +87,23 @@ class Gamdl:
         return response
     
 
-    def get_playlist_music_video(self, webplayback):
-        return m3u8.load(webplayback['hls-playlist-url'])
-    
-
     def get_stream_url_song(self, webplayback):
         return next(i for i in webplayback["assets"] if i["flavor"] == "28:ctrp256")['URL']
     
 
-    def get_stream_url_music_video_audio(self, playlist):
-        return [i for i in playlist.media if i.type == "AUDIO"][-1].uri
-    
-
-    def get_stream_url_music_video_video(self, playlist):
+    def get_stream_url_music_video(self, webplayback):
+        with YoutubeDL({
+            'allow_unplayable_formats': True,
+            'quiet': True,
+            'no_warnings': True,
+        }) as ydl:
+            playlist = ydl.extract_info(webplayback['hls-playlist-url'], download = False)
         if self.prefer_hevc:
-            return playlist.playlists[-1].uri
+            stream_url_video = playlist['formats'][-1]['url']
         else:
-            return [i for i in playlist.playlists if 'avc' in i.stream_info.codecs][-1].uri
+            stream_url_video = [i['url'] for i in playlist['formats'] if i['vcodec'] is not None and 'avc1' in i['vcodec']][-1]
+        stream_url_audio = next(i['url'] for i in playlist['formats'] if 'audio-stereo-256' in i['format_id'])
+        return stream_url_video, stream_url_audio
     
 
     def check_exists(self, final_location):
@@ -190,25 +190,23 @@ class Gamdl:
             ],
             check = True
         )
-    
 
+    
     def get_synced_lyrics_formated_time(self, unformatted_time):
-        if 's' in unformatted_time:
-            unformatted_time = unformatted_time.replace('s', '')
-        if '.' not in unformatted_time:
-            unformatted_time += '.0'
-        s = int(unformatted_time.split('.')[-2].split(':')[-1]) * 1000
-        try:
-            m = int(unformatted_time.split('.')[-2].split(':')[-2]) * 60000
-        except:
-            m = 0
-        ms = f'{int(unformatted_time.split(".")[-1]):03d}'
-        if int(ms[2]) >= 5:
-            ms = int(f'{int(ms[:2]) + 1}') * 10
-        else:
-            ms = int(ms)
-        formated_time = datetime.datetime.fromtimestamp((s + m + ms)/1000.0)
-        return formated_time.strftime('%M:%S.%f')[:-4]
+        unformatted_time = unformatted_time.replace('m', '').replace('s', '').replace(':', '.')
+        unformatted_time = unformatted_time.split('.')
+        m, s, ms = 0, 0, 0
+        ms = int(unformatted_time[-1])
+        if len(unformatted_time) >= 2:
+            s = int(unformatted_time[-2]) * 1000
+        if len(unformatted_time) >= 3:
+            m = int(unformatted_time[-3]) * 60000
+        unformatted_time = datetime.datetime.fromtimestamp((ms + s + m)/1000.0)
+        ms_new = f'{int(str(unformatted_time.microsecond)[:3]):03d}'
+        if int(ms_new[2]) >= 5:
+            ms = int(f'{int(ms_new[:2]) + 1}') * 10
+            unformatted_time += datetime.timedelta(milliseconds=ms) - datetime.timedelta(microseconds=unformatted_time.microsecond)
+        return unformatted_time.strftime('%M:%S.%f')[:-4]
 
 
     def get_lyrics(self, track_id):
